ComparatorMechanism
===================

.. automodule:: psyneulink.library.components.mechanisms.processing.objective.comparatormechanism
   :members:
   :exclude-members: random, validate_monitored_value, add_monitored_values, Parameters
